@@ -175,6 +175,8 @@ OC.L10N.register(
     "If you have problems with this Bookmarks app or have an idea about what could be improved, don't hesitate to get in touch by clicking here." : "Ef þú lendir í vandræðum með bókamerkjaforritið eða hefur hugmyndir um hvernig hægt væri að bæta það, skaltu ekki hika við að hafa samband með því að smella hér.",
     "Support this project" : "Styrkja þetta verkefni",
     "My work on this Bookmarks app is fuelled by a voluntary subscription model. If you think what I do is worthwhile, I would be happy if you could support my work. Also, please consider giving the app a review on the Nextcloud app store. Thank you 💙 " : "Vinnan við þetta bókamerkjaforrit er fjármögnuð með valfrjálsu áskriftarlíkani. Ef þér finnst þetta þess virði, væri ánægjulegt ef þú sæir þér fært að styrkja verkefnið. Eins gætirðu íhugað að gefa forritinu umsögn í Nextcloud-forritaversluninni. Takk kærlega 💙 ",
+    "Created {time} ago" : "Búið til fyrir {time} síðan",
+    "Created on {date}" : "Búið til {date}",
     "(Empty title)" : "(auður titill)",
     "Title" : "Titill",
     "Link" : "Tengill",
@@ -185,6 +187,7 @@ OC.L10N.register(
     "Notes" : "Minnispunktar",
     "Notes for this bookmark …" : "Minnispunktur á þetta bókamerki …",
     "Archived file" : "Skrá í safni",
+    "Open file" : "Opna skrá",
     "Download file" : "Sækja skrá",
     "Open file location" : "Opna staðsetningu skráar",
     "Link copied" : "Tengill afritaður",
@@ -245,6 +248,7 @@ OC.L10N.register(
     "Failed to move bookmark" : "Mistókst að færa bókamerki",
     "Failed to copy bookmark" : "Mistókst að afrita bókamerki",
     "Failed to delete bookmark" : "Mistókst að eyða bókamerki",
+    "Import successful" : "Innflutningur tókst",
     "Failed to rename tag" : "Mistókst að endurnefna merki",
     "Failed to load tags" : "Mistókst að hlaða inn merkjum",
     "Failed to load folders" : "Mistókst að hlaða inn möppum",
@@ -253,6 +257,8 @@ OC.L10N.register(
     "Failed to delete folder" : "Mistókst að eyða möppu",
     "Failed to move folder" : "Mistókst að færa möppu",
     "Failed to create folder" : "Mistókst að búa til möppu",
+    "Failed to move parts of selection" : "Mistókst að færa hluta af völdu",
+    "Failed to delete parts of selection" : "Mistókst að eyða hluta af völdu",
     "Failed to fetch bookmarks." : "Ekki tókst að sækja bókamerki.",
     "Failed to store setting" : "Mistókst að geyma stillingu",
     "Failed to load setting {key}" : "Mistókst að hlaða inn {key} stillingunni",
