@@ -35,7 +35,9 @@ OC.L10N.register(
     "Tags" : "Birkas",
     "Notes" : "Piezīmes",
     "Notes for this bookmark …" : "Šīs grāmatzīmes piezīmes …",
+    "Open file" : "Atvērt datni",
     "Download file" : "Lejupielādēt datni",
+    "Open file location" : "Atvērt datnes atrašanās vietu",
     "Link copied" : "Saite nokopēta",
     "Owner" : "Īpašnieks",
     "Sharing" : "Koplietošana",
