@@ -21,11 +21,13 @@ OC.L10N.register(
     "Files" : "Fișiere",
     "Delete" : "Șterge",
     "Need help?" : "Ai nevoie de ajutor?",
+    "Created on {date}" : "Creat la {date}",
     "Title" : "Titlu",
     "Link" : "Legătură",
     "Root folder" : "Folder principal",
     "Tags" : "Etichete",
     "Notes" : "Notițe",
+    "Open file" : "Deschide fișier",
     "Download file" : "Descarcă fișier",
     "Link copied" : "Link copiat",
     "Owner" : "Proprietar",
